@@ -23,52 +23,46 @@ from aliyunsdkvod.endpoint import endpoint_data
 class DescribeVodDomainUsageDataRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'vod', '2017-03-21', 'DescribeVodDomainUsageData')
+		RpcRequest.__init__(self, 'vod', '2017-03-21', 'DescribeVodDomainUsageData','vod')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_StartTime(self):
+	def get_StartTime(self): # String
 		return self.get_query_params().get('StartTime')
 
-	def set_StartTime(self,StartTime):
-		self.add_query_param('StartTime',StartTime)
-
-	def get_Type(self):
+	def set_StartTime(self, StartTime):  # String
+		self.add_query_param('StartTime', StartTime)
+	def get_Type(self): # String
 		return self.get_query_params().get('Type')
 
-	def set_Type(self,Type):
-		self.add_query_param('Type',Type)
-
-	def get_Area(self):
+	def set_Type(self, Type):  # String
+		self.add_query_param('Type', Type)
+	def get_Area(self): # String
 		return self.get_query_params().get('Area')
 
-	def set_Area(self,Area):
-		self.add_query_param('Area',Area)
-
-	def get_DomainName(self):
+	def set_Area(self, Area):  # String
+		self.add_query_param('Area', Area)
+	def get_DomainName(self): # String
 		return self.get_query_params().get('DomainName')
 
-	def set_DomainName(self,DomainName):
-		self.add_query_param('DomainName',DomainName)
-
-	def get_EndTime(self):
+	def set_DomainName(self, DomainName):  # String
+		self.add_query_param('DomainName', DomainName)
+	def get_EndTime(self): # String
 		return self.get_query_params().get('EndTime')
 
-	def set_EndTime(self,EndTime):
-		self.add_query_param('EndTime',EndTime)
-
-	def get_OwnerId(self):
+	def set_EndTime(self, EndTime):  # String
+		self.add_query_param('EndTime', EndTime)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_Field(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_Field(self): # String
 		return self.get_query_params().get('Field')
 
-	def set_Field(self,Field):
-		self.add_query_param('Field',Field)
\ No newline at end of file
+	def set_Field(self, Field):  # String
+		self.add_query_param('Field', Field)
