@@ -23,76 +23,66 @@ from aliyunsdkvod.endpoint import endpoint_data
 class ProduceEditingProjectVideoRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'vod', '2017-03-21', 'ProduceEditingProjectVideo')
+		RpcRequest.__init__(self, 'vod', '2017-03-21', 'ProduceEditingProjectVideo','vod')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_Description(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_Description(self): # String
 		return self.get_query_params().get('Description')
 
-	def set_Description(self,Description):
-		self.add_query_param('Description',Description)
-
-	def get_Title(self):
+	def set_Description(self, Description):  # String
+		self.add_query_param('Description', Description)
+	def get_Title(self): # String
 		return self.get_query_params().get('Title')
 
-	def set_Title(self,Title):
-		self.add_query_param('Title',Title)
-
-	def get_CoverURL(self):
+	def set_Title(self, Title):  # String
+		self.add_query_param('Title', Title)
+	def get_CoverURL(self): # String
 		return self.get_query_params().get('CoverURL')
 
-	def set_CoverURL(self,CoverURL):
-		self.add_query_param('CoverURL',CoverURL)
-
-	def get_UserData(self):
+	def set_CoverURL(self, CoverURL):  # String
+		self.add_query_param('CoverURL', CoverURL)
+	def get_UserData(self): # String
 		return self.get_query_params().get('UserData')
 
-	def set_UserData(self,UserData):
-		self.add_query_param('UserData',UserData)
-
-	def get_ProduceConfig(self):
+	def set_UserData(self, UserData):  # String
+		self.add_query_param('UserData', UserData)
+	def get_ProduceConfig(self): # String
 		return self.get_query_params().get('ProduceConfig')
 
-	def set_ProduceConfig(self,ProduceConfig):
-		self.add_query_param('ProduceConfig',ProduceConfig)
-
-	def get_ProjectId(self):
+	def set_ProduceConfig(self, ProduceConfig):  # String
+		self.add_query_param('ProduceConfig', ProduceConfig)
+	def get_ProjectId(self): # String
 		return self.get_query_params().get('ProjectId')
 
-	def set_ProjectId(self,ProjectId):
-		self.add_query_param('ProjectId',ProjectId)
-
-	def get_MediaMetadata(self):
+	def set_ProjectId(self, ProjectId):  # String
+		self.add_query_param('ProjectId', ProjectId)
+	def get_MediaMetadata(self): # String
 		return self.get_query_params().get('MediaMetadata')
 
-	def set_MediaMetadata(self,MediaMetadata):
-		self.add_query_param('MediaMetadata',MediaMetadata)
-
-	def get_ResourceOwnerAccount(self):
+	def set_MediaMetadata(self, MediaMetadata):  # String
+		self.add_query_param('MediaMetadata', MediaMetadata)
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_OwnerId(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_Timeline(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_Timeline(self): # String
 		return self.get_query_params().get('Timeline')
 
-	def set_Timeline(self,Timeline):
-		self.add_query_param('Timeline',Timeline)
\ No newline at end of file
+	def set_Timeline(self, Timeline):  # String
+		self.add_query_param('Timeline', Timeline)
